#!/bin/sh
# find wish wherever it is \
exec wish -f "$0" ${1+"$@"}

# platform.tcl
# Charles Andr
# February 18, 2000
# modif: July 19, 2000: access to xeve and xes for Linux2
# November 19, 2000: simplified for Linux 2.2 only 
# November 29, 2000: new simplification (use of launcher.tcl)
# December 16, 2000: include unixCon.tcl
# December 23, 2000: made independent of the tcl-dir

# November 6, 2002: port to Linux2.4
# January 28, 2004: update for windows and cygwin

# Purpose: set localCfg to the current OS version
# Modify localCfg, flexCfg in $(HOME)
# January 31, 2004: cygwin as an OS
# April 15, 2004: Cygwin instead of cygwin as OS

wm withdraw .

set HOMEDIR $env(HOME)
set SOFTDIR $env(SOFTDIR)
# make the path a unix path in any case
set SOFTDIR [join [split $SOFTDIR \\] /]

# retrieve information from the underlying system
set PF  $tcl_platform(platform)
set OS  $tcl_platform(os)
set VOS $tcl_platform(osVersion)

proc plf_help {} {
    tk_messageBox -type ok -title "Help" -parent . \
	    -message "platform.tcl: Usage\n\n\
	    \ platform.tcl \[-- Options\]\n\
	    Options:\n\
	    \ -cygwin \n\
	    \ -help \n\
	    \n"
}

proc plf_usage { } {
    
    putsStderr "\nUsage: platform.tcl ?-hc?"
    putsStderr "\twhere"
    putsStderr "\t\th\t stands for help;"
    putsStderr "\t\tc\t running on cygwin;"
    putsStderr " "
    
}

# default settings
set state flag

# parse the argument list
foreach arg $argv {
    switch -- $state {
	flag {
	    switch -glob -- $arg {
		-h* {
		    # help
		    plf_help
		    exit
		}
		-c* {
		    # can't be automatically detected, so force it!
		    set PF unix
		    set OS Cygwin
		    set VOS ""
		}
		default {
		    # unknown option
		    plf_help
		    exit	
		}
	    }
	}
    }
}


set SRCDIR  $SOFTDIR/bin

# choose putStderr
if [string compare $PF "windows" ] {
    proc putsStderr { args } {
	uplevel #0 puts stderr "$args"
    }
} else { 
    source [file join $SRCDIR pseudoCon.tcl]
}

# system informations	
set EXT Unknown

switch $PF {
    unix {
	# Binaries
	if { $OS == "Linux" } {
	    set l [split $VOS .]
	    set V    [lindex $l 0]
	    set MAJV [lindex $l 1]
	    set MINV [lindex $l 2]
	    if { $V != 2 } {
		putsStderr "$VOS: Unsupported Linux version"
		exit
	    }
	    switch -- $MAJV {
		0 {
		    putsStderr "Sorry! Linux 2.0.XX no longer supported"
		    # set EXT Linux2.0
		}
		2 {
		    set EXT Linux2
		    # exec $SRCDIR/selFss  2
		    # exec cp $SRCDIR/rtLinux.sh ${HOMEDIR}/bin/rt
		}
		4 {
		    set EXT Linux4
		}
		6 {
		    set EXT Linux4
		}
		default {
		    putsStderr "$VOS: Unsupported Linux version"
		    exit
		}
	    }
	} elseif { $OS == "Cygwin" } {
	    set EXT Cygwin	
	} elseif { $OS == "Solaris" } {
	    # Solaris
	}      
    }
    windows {
	# Windows
	set EXT Windows
    }
}

proc stripCygwin {fn} {

    if [regexp {(.*)/home/(.*)} $fn match head tail] {
	return  "/home/$tail"
    }
    return $fn
}

if { $EXT != "Unknown" } {
    # exec cp  $SRCDIR/localCfg.$EXT ${HOMEDIR}/localCfg
    # exec cp  $SRCDIR/flexCfg.$EXT ${HOMEDIR}/flexCfg
    set oldDir [pwd]
    cd $SRCDIR
    if { $OS == "Cygwin" } {
	if [catch {open $HOMEDIR/localCfg w} f] {
	    tk_messageBox -message "Can't write ~/localCfg" \
		-icon error -type ok
	    exit
	} else {
	    set HOME [stripCygwin $HOMEDIR]
	    puts $f "\# localCfg.Cygwin -- Charles Andr"
	    puts $f "\# Creation: [clock format [clock seconds]]"
	    puts $f "OS = Cygwin"
	    puts $f "HOME = $HOME"
	    puts $f "EXT = .exe"
	    puts $f "SOFTDIR = $HOME/tools"
	    puts $f "RTLOS = $SOFTDIR/RTL/Linux"
	    puts $f "include $SOFTDIR/bin/localCfgCommon"
	    puts $f ""
	    close $f
	}
    } else {
	file copy -force localCfg.$EXT [file join $HOMEDIR localCfg]
    }
    file copy -force flexCfg.$EXT [file join $HOMEDIR flexCfg]    
    
    cd $oldDir
    putsStderr "$HOMEDIR updated for $OS $VOS"
} else {
    putsStderr "Sorry! $OS $VOS not supported"
}

tk_dialog .wexit Platform "Installation finished" info 0 Terminate
exit







